@@ -31,7 +31,7 @@ class MDSimulation():
     from ommtk import MDSimulation, select_atoms
 
     #instantiate sim from parmed alone, minimize (save h5 file) and run
-    mdsim = MDSimulation(parmed_structure=parmed)
+    >>> mdsim = MDSimulation(parmed_structure=parmed)
     mdsim.minimize()
     minimized_parmed = mdsim.run(2 * unit.nanosecond)
 
@@ -393,7 +393,7 @@ class MDSimulation():
 
         virt_bond = mm.CustomBondForce(' 0 * r')
 
-        print(atom_selection1,atom_selection2)
+        # print(atom_selection1,atom_selection2)
         virt_bond.addBond(atom_selection1,atom_selection2)
         self.custom_forces['Virtual_Bond'] = self.system.addForce((virt_bond))
 
@@ -1013,7 +1013,6 @@ class GentleHeatSimulation(MDSimulation):
         self.simulation.reporters.clear()
         return self.parmed_structure
 
-
 class MetadynamicSimulation(MDSimulation):
     """
     Metadynamics Simulation Class
@@ -1102,6 +1101,9 @@ class MetadynamicSimulation(MDSimulation):
     fes_interval : unit.Quantity, optional
         frequency with which to write FES and CV values to disk
 
+    reference_coordinates : positions
+        openMM format coordinates for RMSD bias
+
 
     """
 
@@ -1377,7 +1379,6 @@ class SimulatedTemperingSimulation(MDSimulation):
         return self.parmed_structure
 
 
-
 if __name__ == '__main__':
     import _pickle as pickle
 
