@@ -334,7 +334,7 @@ class SegmentMappingSim(MetadynamicSimulation):
 
 class SegmentMappingSimHREMD(SegmentMappingSim):
 
-    def __init__(self, max_production_time=200 * unit.nanosecond, min_production_time = 5 * unit.nanosecond,
+    def __init__(self, max_production_time=60 * unit.nanosecond, min_production_time = 5 * unit.nanosecond,
                  swap_freq = 2 * unit.nanosecond, convergence_window=2 * unit.nanosecond,
                  dG_displacement_criteria = 1, min_coverage_criteria=.25,
                  **kwargs):
@@ -448,7 +448,7 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
                 dG_std < self.convergence_criteria and \
                 dG_displacement < self.dG_displacement_criteria:
                 print("""convergence detected! Final dG {}:, coverage 
-                      {}, dG_std: {}, dG_displacement: {}""".format(dG_trace[-1],coverage,dG_std,dG_displacement))
+                      {}, dG_std: {}, dG_displacement: {}""".format(dG_trace[-1],coverage * 100,dG_std,dG_displacement))
                 continue_simulating= False
 
             #or complete when max time is hit
